/*
Copyright (c) 2007 Matt Williams matt@milliams.com

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License or (at
your option) version 3 or, at the discretion of KDE e.V. (which shall
act as a proxy as in section 14 of the GPLv3), any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KQTISIMPLECHOICE_H
#define KQTISIMPLECHOICE_H

#include "kqtichoice.h"

#include <kqti_export.h>
#include <QDomElement>
#include <QList>

class KQtiFlowStatic;

/**
 * \class KQtiSimpleChoice
 * simpleChoice is a choice that contains flowStatic objects. A simpleChoice
 * must not contain any nested interactions.
 * 
 * http://www.imsglobal.org/question/qtiv2p1pd2/imsqti_infov2p1pd2.html#element10289
 */

class KQTI_EXPORT KQtiSimpleChoice : public KQtiChoice
{
    public:
        explicit KQtiSimpleChoice(const QString& identifier, bool fixed=false);
        explicit KQtiSimpleChoice(const QDomElement& element);
        ~KQtiSimpleChoice();
        
        void addFlowStatic(KQtiFlowStatic* flowStatic);
        QList<KQtiFlowStatic*> flowStatics() const {return mFlowStatics;}
        
        /**
         * element
         * @return create and return the DOM element
         */
        QDomElement element() const;
        
    protected:
        QList<KQtiFlowStatic*> mFlowStatics; //[*]
};

#endif
